@@ -230,7 +230,10 @@ class MCPropagation:
 
         for i in range(len(x)):
             if u_x[i] is None:
-                u_x[i] = np.zeros(x[i].shape)
+                if hasattr(x[i],"__len__"):
+                    u_x[i] = np.zeros(x[i].shape)
+                else:
+                    u_x[i] = 0.
 
         if isinstance(repeat_dims,int):
             repeat_axis = repeat_dims
